@@ -11,7 +11,7 @@ def render_literal_value(literal_value) -> str:
 
 @render_literal_value.instance(None)
 def _render_none(literal_value: None) -> str:
-    return '∅ None'
+    return f'∅ {literal_value}'
 
 
 @render_literal_value.instance(bool)
