@@ -1,10 +1,10 @@
 from abc import ABC
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 from typing import Iterable, Optional, TextIO
 
-from iolanta.models import ContextAliases, LDContext, LDDocument, Quad
+from iolanta.loaders.base import Loader
+from iolanta.models import LDContext, LDDocument, Quad
 from rdflib import URIRef
-from urlpath import URL
 
 
 @dataclass(frozen=True)
@@ -17,15 +17,22 @@ class Parser(ABC):
 
     blank_node_prefix: str = ''
 
-    def as_jsonld_document(self, raw_data: TextIO) -> LDDocument:
+    def as_jsonld_document(
+        self,
+        raw_data: TextIO,
+    ) -> LDDocument:
         """Generate a JSON-LD document."""
-        raise NotImplementedError()
+        raise NotImplementedError(
+            f'{self}.as_json_document() is not implemented.',
+        )
 
     def as_quad_stream(
         self,
         raw_data: TextIO,
         iri: Optional[URIRef],
         context: LDContext,
+        root_loader: Loader,
     ) -> Iterable[Quad]:
-        raise NotImplementedError()
-
+        raise NotImplementedError(
+            f'{self}.as_quad_stream() is not implemented.',
+        )
