@@ -1,3 +1,4 @@
+import itertools
 import json
 from dataclasses import dataclass, replace
 from typing import Any, Iterable, Optional, TextIO
@@ -10,7 +11,7 @@ from iolanta.parsers.base import Parser
 from octadocs.types import OCTA
 from pyld import jsonld
 from pyld.jsonld import JsonLdError
-from rdflib import XSD, URIRef
+from rdflib import XSD, URIRef, RDF
 from rdflib.term import BNode, Literal, Node
 
 
@@ -93,18 +94,22 @@ def parse_term(
         return URIRef(term_value)
 
     if term_type == 'literal':
-        datatype = term.get('datatype')
+        language = term.get('language')
 
-        if datatype is not None:
+        if datatype := term.get('datatype'):
             datatype = URIRef(datatype)
 
             # XSD.string does not provide any extra information. Removing it.
             if datatype == XSD.string:
                 datatype = None
 
+        if language and datatype:
+            datatype = None
+
         return Literal(
             term_value,
             datatype=datatype,
+            lang=language,
         )
 
     if term_type == 'blank node':
@@ -196,12 +201,19 @@ class JSON(Parser):
 
         document = jsonld.flatten(document)
 
+        static_quads = [
+            Quad(iri, RDF.type, OCTA.File, iri),
+        ]
+
         return list(
-            parse_quads(
-                quads_document=jsonld.to_rdf(document),
-                graph=iri,
-                blank_node_prefix=str(iri),
-            ),
+            itertools.chain(
+                parse_quads(
+                    quads_document=jsonld.to_rdf(document),
+                    graph=iri,
+                    blank_node_prefix=str(iri),
+                ),
+                static_quads,
+            )
         )
 
 
