@@ -2,13 +2,12 @@ import sys
 from pathlib import Path
 from typing import Optional
 
+from typer import Argument, Option, Typer
+
 from ldflex import LDFlex
-from octadocs.cli.formatters.csv import csv_print
-from octadocs.cli.formatters.json import print_json
-from octadocs.cli.formatters.pretty import pretty_print
+from octadocs.cli.formatters.choose import cli_print
 from octadocs.storage import load_graph
 from octadocs.types import QueryResultsFormat
-from typer import Argument, Option, Typer
 
 app = Typer(name='sparql')
 
@@ -24,6 +23,10 @@ def sparql(
         metavar='query',
         help='SPARQL query text. Will be read from stdin if empty.',
     ),
+    use_qnames: bool = Option(
+        default=True,
+        help='Collapse URLs into QNames.',
+    ),
 ) -> None:
     """Run a SPARQL query against the graph."""
     if query_text is None:
@@ -34,8 +37,9 @@ def sparql(
 
     query_result = ldflex.query(query_text)
 
-    {
-        QueryResultsFormat.CSV: csv_print,
-        QueryResultsFormat.PRETTY: pretty_print,
-        QueryResultsFormat.JSON: print_json,
-    }[fmt](query_result)   # type: ignore
+    cli_print(
+        query_result=query_result,
+        output_format=fmt,
+        display_iri_as_qname=use_qnames,
+        graph=graph,
+    )
