@@ -1,2 +1,2 @@
 from octadocs.facets.date_literal import DateLiteral
-from octadocs.facets.default import default
+from octadocs.facets.default import Default
