@@ -18,8 +18,8 @@ class FacetNotCallable(DocumentedError):
           - Import path: `{self.path}`
           - Object imported: `{self.facet}`
 
-        The imported Python object is not a callable and thus cannot be used as a
-        facet.
+        The imported Python object is not a callable and thus cannot be used as
+        a facet.
     """
 
     path: str
@@ -50,7 +50,8 @@ class FacetNotFound(DocumentedError):
         """Node type."""
         node_type = type(self.node).__name__
         if isinstance(self.node, Literal):
-            node_type = f'{node_type}, datatype={self.node.datatype}'
+            datatype = self.node.datatype
+            node_type = f'{node_type}, datatype={datatype}'
 
         return node_type
 
@@ -75,15 +76,13 @@ class FacetError(DocumentedError):
         - Node: `{self.node}`
         - Facet IRI: `{self.facet_iri}`
 
-        Why was this facet chosen for this node, at the first place?
-
-        ### {self.render_facet_search_attempt}
-
         ### Exception
 
-        ```
-        {self.error}
-        ```
+        {self.indented_error}
+
+        Why was this facet at all chosen for this node?
+
+        ### {self.render_facet_search_attempt}
     """
 
     node: Node
@@ -93,7 +92,16 @@ class FacetError(DocumentedError):
 
     @property
     def render_facet_search_attempt(self):
+        """Render facet search attempt."""
         return textwrap.indent(
             f'\n## {self.facet_search_attempt}',
             '    ',
         )
+
+    @property
+    def indented_error(self):
+        """Format the underlying error text."""
+        return textwrap.indent(
+            str(self.error),
+            prefix='    ',
+        )
