@@ -3,7 +3,7 @@ from functools import lru_cache
 from pathlib import Path
 
 import yaml
-from octadocs.octiron.yaml_extensions import convert_dollar_signs
+from iolanta.convert_dollar_signs import convert_dollar_signs
 from octadocs.types import Context
 
 
