@@ -1,7 +1,7 @@
 import logging
 import operator
 import re
-from functools import lru_cache, partial
+from functools import lru_cache, partial, cached_property
 from pathlib import Path
 from typing import Any, Callable, Dict, Optional
 
@@ -11,12 +11,17 @@ from mkdocs.plugins import BasePlugin
 from mkdocs.structure.files import Files
 from mkdocs.structure.nav import Navigation
 from mkdocs.structure.pages import Page
+from urlpath import URL
+
+from iolanta import as_document
+from iolanta.models import LDDocument
 from octadocs.conversions import iri_by_page, src_path_to_iri
 from octadocs.default_context import construct_root_context
 from octadocs.iolanta import render
 from octadocs.iolanta.errors import FacetNotFound
 from octadocs.iolanta.iolanta import Render
 from octadocs.macros import link
+from octadocs.language_from_config import language_from_config
 from octadocs.navigation.processor import OctadocsNavigationProcessor
 from octadocs.octiron import Octiron
 from octadocs.query import query
@@ -65,13 +70,14 @@ class TemplateContext(TypedDict):
 
 
 @lru_cache(None)
-def cached_octiron(docs_dir: Path) -> Octiron:
+def cached_octiron(docs_dir: Path, language: Optional[str]) -> Octiron:
     """Retrieve cached Octiron instance or create it if absent."""
     return Octiron(
         root_directory=docs_dir,
         root_context=construct_root_context(
             namespaces=DEFAULT_NAMESPACES,
         ),
+        language=language,
     )
 
 
@@ -81,12 +87,22 @@ class OctaDocsPlugin(BasePlugin):
     octiron: Octiron
     stored_query: StoredQuery
 
+    def retrieve_named_context(self, relative_path: str) -> LDDocument:
+        """Construct URL to the named context file."""
+        return as_document(
+            URL(
+                'file://',
+                Path(__file__).parent / 'data' / relative_path,
+            ),
+        )
+
     def on_config(self, config: Config) -> Config:
         """Initialize Octiron and provide graph to macros through the config."""
         docs_dir = Path(config['docs_dir'])
 
         self.octiron = cached_octiron(
             docs_dir=docs_dir,
+            language=language_from_config(config),
         )
 
         self.stored_query = StoredQuery(
@@ -104,7 +120,15 @@ class OctaDocsPlugin(BasePlugin):
             'graph': self.octiron.graph,
             'octiron': self.octiron,
             'queries': self.stored_query,
-            'named_contexts': {},
+
+            'named_contexts': {
+                'rdfs': self.retrieve_named_context('rdfs/named-context.json'),
+                'iolanta': self.retrieve_named_context(
+                    'iolanta/named-context.json',
+                ),
+                'owl': self.retrieve_named_context('owl/named-context.json'),
+                # 'octa': self.retrieve_named_context('octa/named-context.json'),
+            },
         })
 
         return config
@@ -144,25 +168,38 @@ class OctaDocsPlugin(BasePlugin):
     ):
         """Inject page template path, if necessary."""
         page.iri = iri_by_page(page)
+        page.id = self.id_by_page.get(page.iri, page.iri)
 
         try:
             template_url = Render(
                 ldflex=self.octiron.ldflex,
             ).find_facet_iri(
-                node=page.iri,
+                node=page.id,
                 environments=[URIRef(OCTA)],
             )
         except FacetNotFound:
             return markdown
 
         page.meta['template'] = re.sub(
-            '^templates:',
+            '^templates:/*',
             '',
             template_url,
         )
 
         return markdown
 
+    @cached_property
+    def id_by_page(self) -> Dict[URIRef, URIRef]:
+        """Retrieve the best suitable IRI for an MkDocs page."""
+        rows = self.octiron.ldflex.query(
+            'SELECT ?page ?this WHERE { ?this octa:subjectOf ?page . }',
+        )
+
+        return {
+            row['page']: row['this']
+            for row in rows
+        }
+
     def on_page_context(
         self,
         context: TemplateContext,
@@ -175,21 +212,7 @@ class OctaDocsPlugin(BasePlugin):
             f'{LOCAL}{page.file.src_path}',
         )
 
-        this_choices = list(map(
-            operator.itemgetter(rdflib.Variable('this')),
-            self.octiron.graph.query(
-                'SELECT * WHERE { ?this octa:subjectOf ?page_iri }',
-                initBindings={
-                    'page_iri': page_iri,
-                },
-            ).bindings,
-        ))
-
-        if this_choices:
-            context['this'] = this_choices[0]
-        else:
-            context['this'] = page_iri
-
+        context['this'] = context['id'] = self.id_by_page.get(page_iri, page_iri)
         context['graph'] = self.octiron.graph
         context['iri'] = page_iri
 
@@ -218,6 +241,7 @@ class OctaDocsPlugin(BasePlugin):
 
         # Page attributes
         page.iri = page_iri
+        page.id = self.id_by_page.get(page_iri, page_iri)
 
         return context
 
