@@ -1,39 +1,9 @@
-from typing import Dict, List, Optional, Union
+from typing import Dict, List
 
 import rdflib
-from rdflib import Graph, term
+from octadocs.types import QueryResult, SelectResult
+from rdflib import term
 from rdflib.plugins.sparql.processor import SPARQLResult
-from typing_extensions import Protocol
-
-SelectRow = Dict[str, term.Node]
-
-
-class SelectResult(List[SelectRow]):
-    """SPARQL SELECT query result."""
-
-    @property
-    def first(self) -> Optional[SelectRow]:
-        """Return first element of the list."""
-        return self[0] if self else None
-
-
-QueryResult = Union[
-    SelectResult,   # SELECT
-    Graph,          # CONSTRUCT
-    bool,           # ASK
-]
-
-
-class Query(Protocol):
-    """Query protocol."""
-
-    def __call__(
-        self,
-        query_text: str,
-        instance: rdflib.ConjunctiveGraph,
-        **kwargs: str,
-    ) -> QueryResult:
-        """Query prototype."""
 
 
 def query(
