@@ -66,8 +66,13 @@ def construct_row(
     query_text = '''
     SELECT * WHERE {
         $instance ?column ?value .
+
+        OPTIONAL {
+            ?value octa:trustLevel ?trust_level .
+        }
+
         FILTER(?column IN %s) .
-    }
+    } ORDER BY ?column ?trust_level
     ''' % formatted_columns
 
     cells = octiron.query(
@@ -80,6 +85,10 @@ def construct_row(
         'value': instance,
     })
 
+    # This dictionary comprehension entails an implicit deduplication by
+    # `cell['column']`, in which the last duplicate wins. Since we have sorted
+    # the elements by `octa:trustLevel` this means we will prefer a higher trust
+    # level over a lower one, or over an absence of defined trust level.
     return {
         cell['column']: instance if (
             cell['column'] == TABLE.self
