@@ -3,6 +3,8 @@ from typing import Any, Dict
 
 from mkdocs.plugins import BasePlugin
 from mkdocs.structure.pages import Page
+
+from octadocs.language_from_config import language_from_config
 from octadocs.octiron.context_loaders import context_from_yaml
 from octadocs.plugin import cached_octiron
 from octadocs_table.models import TABLE
@@ -43,6 +45,7 @@ class TablePlugin(BasePlugin):
 
         self.octiron = cached_octiron(
             docs_dir=docs_dir,
+            language=language_from_config(config),
         )
 
         # Prefix
